@@ -1,6 +1,6 @@
 use anchor_lang::prelude::*;
 
-#[error]
+#[error_code]
 pub enum ErrorCode {
     #[msg("Token account not owned by the claim approver")]
     InvalidPaymentTokenAccount,
@@ -21,5 +21,7 @@ pub enum ErrorCode {
     #[msg("Max expiration exceeded")]
     InvalidExtendExpiration,
     #[msg("Invalid payment mint on time invalidator")]
-    InvalidPaymentMint
+    InvalidPaymentMint,
+    #[msg("Invalid extension partial duration not allowed")]
+    InvalidExtensionAmount
 }
\ No newline at end of file
